0.5.0 - Released on 2025-03-10
------------------------------
* Remove asyncio support

0.4.0 - Released on 2025-03-10
------------------------------
* Now autorize async method for given when then decorated methods
* Implement tags converted to pytest marker
* Implement Rule (do nothing except adding tags)

0.3.1 - Released on 2025-03-10
------------------------------
* Fix annotation support for literal, enums, boolean and float types

0.3.0 - Released on 2025-03-10
------------------------------
* Add support of docstring in tests

0.2.0 - Released on 2025-03-09
------------------------------
* Implement a tursu init command
* Implement the Background keyword

0.1.3 - Released on 2025-03-09
------------------------------
* Publish the doc

0.1.2 - Released on 2025-03-09
------------------------------
* Initial release

